componenttools.get_nth_namesake_from_component
==============================================

.. autofunction:: abjad.tools.componenttools.get_nth_namesake_from_component.get_nth_namesake_from_component
